@@ -1190,27 +1190,33 @@ node_derivative(Node * node, char *name, SymbolTable * symbol_table)
 		/* Apply rule of erf function derivative. */
 		else if (!strcmp(node->data.function.record->name, "erf"))
 			return node_create('b', '*',
-					   node_create('c',
-						       symbol_table_lookup
-						       (symbol_table,
-							"2_sqrtpi")),
-					   node_create('f',
-						       symbol_table_lookup
-						       (symbol_table,
-							"exp"),
-						       node_create('u',
-								   '-',
+					   node_derivative(node->data.
+							   function.child,
+							   name,
+							   symbol_table),
+					   node_create('b', '*',
+						       node_create('c',
+								   symbol_table_lookup
+								   (symbol_table,
+								    "2_sqrtpi")),
+						       node_create('f',
+								   symbol_table_lookup
+								   (symbol_table,
+								    "exp"),
 								   node_create
-								   ('b',
-								    '^',
-								    node_copy
-								    (node->
-								     data.
-								     function.
-								     child),
+								   ('u',
+								    '-',
 								    node_create
-								    ('n',
-								     2.0)))));
+								    ('b',
+								     '^',
+								     node_copy
+								     (node->
+								      data.
+								      function.
+								      child),
+								     node_create
+								     ('n',
+								      2.0))))));
 
 	case 'u':
 		switch (node->data.un_op.operation) {
