@@ -1,6 +1,6 @@
 /* 
- * Copyright (C) 1999, 2002, 2003, 2004, 2005, 2006, 2007 Free Software
- * Foundation, Inc.
+ * Copyright (C) 1999, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free
+ * Software Foundation, Inc.
  * 
  * This file is part of GNU libmatheval
  * 
@@ -60,11 +60,11 @@ symbol_table_create(int length)
 		"csc", "asin", "acos", "atan", "acot", "asec", "acsc",
 		"sinh", "cosh", "tanh", "coth", "sech", "csch",
 		"asinh", "acosh", "atanh", "acoth", "asech", "acsch",
-		"abs", "step", "delta", "nandelta"
+		"abs", "step", "delta", "nandelta", "erf", 
 	};			/* Symbol table predefined functions
 				 * names. */
 	static double   (*functions[]) (double) = {
-	exp, log, sqrt, sin, cos, tan, math_cot, math_sec, math_csc, asin, acos, atan, math_acot, math_asec, math_acsc, sinh, cosh, tanh, math_coth, math_sech, math_csch, math_asinh, math_acosh, math_atanh, math_acoth, math_asech, math_acsch, fabs, math_step, math_delta, math_nandelta};	/* Symbol 
+	exp, log, sqrt, sin, cos, tan, math_cot, math_sec, math_csc, asin, acos, atan, math_acot, math_asec, math_acsc, sinh, cosh, tanh, math_coth, math_sech, math_csch, math_asinh, math_acosh, math_atanh, math_acoth, math_asech, math_acsch, fabs, math_step, math_delta, math_nandelta, erf};	/* Symbol 
 																																				 * table 
 																																				 * predefined 
 																																				 * functions 
